==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/LikenessFeatures.java <==
package com.example.model;

/**
 * Model for LikenessFeatures
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "LikenessFeatures", description = "Model for LikenessFeatures")
@javax.xml.bind.annotation.XmlRootElement(name = "LikenessFeatures")
public class LikenessFeatures implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String forehead = null;
	private java.lang.String jaw = null;
	private java.lang.String leftBrow = null;
	private java.lang.String leftCheek = null;
	private java.lang.String leftEye = null;
	private java.lang.String middleForehead = null;
	private java.lang.String mouth = null;
	private java.lang.String nose = null;
	private java.lang.String philtrum = null;
	private java.lang.String rightBrow = null;
	private java.lang.String rightCheek = null;
	private java.lang.String rightEye = null;
	
	/**
	 */
	public LikenessFeatures forehead(java.lang.String forehead) {
		setForehead(forehead);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("forehead")
	@javax.validation.constraints.NotNull
	public java.lang.String getForehead() {
		return this.forehead;
	}
	public void setForehead(java.lang.String forehead) {
		this.forehead = forehead;
	}
	
	/**
	 */
	public LikenessFeatures jaw(java.lang.String jaw) {
		setJaw(jaw);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("jaw")
	public java.lang.String getJaw() {
		return this.jaw;
	}
	public void setJaw(java.lang.String jaw) {
		this.jaw = jaw;
	}
	
	/**
	 */
	public LikenessFeatures leftBrow(java.lang.String leftBrow) {
		setLeftBrow(leftBrow);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("left_brow")
	public java.lang.String getLeftBrow() {
		return this.leftBrow;
	}
	public void setLeftBrow(java.lang.String leftBrow) {
		this.leftBrow = leftBrow;
	}
	
	/**
	 */
	public LikenessFeatures leftCheek(java.lang.String leftCheek) {
		setLeftCheek(leftCheek);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("left_cheek")
	public java.lang.String getLeftCheek() {
		return this.leftCheek;
	}
	public void setLeftCheek(java.lang.String leftCheek) {
		this.leftCheek = leftCheek;
	}
	
	/**
	 */
	public LikenessFeatures leftEye(java.lang.String leftEye) {
		setLeftEye(leftEye);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("left_eye")
	public java.lang.String getLeftEye() {
		return this.leftEye;
	}
	public void setLeftEye(java.lang.String leftEye) {
		this.leftEye = leftEye;
	}
	
	/**
	 */
	public LikenessFeatures middleForehead(java.lang.String middleForehead) {
		setMiddleForehead(middleForehead);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("middle_forehead")
	public java.lang.String getMiddleForehead() {
		return this.middleForehead;
	}
	public void setMiddleForehead(java.lang.String middleForehead) {
		this.middleForehead = middleForehead;
	}
	
	/**
	 */
	public LikenessFeatures mouth(java.lang.String mouth) {
		setMouth(mouth);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("mouth")
	public java.lang.String getMouth() {
		return this.mouth;
	}
	public void setMouth(java.lang.String mouth) {
		this.mouth = mouth;
	}
	
	/**
	 */
	public LikenessFeatures nose(java.lang.String nose) {
		setNose(nose);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("nose")
	public java.lang.String getNose() {
		return this.nose;
	}
	public void setNose(java.lang.String nose) {
		this.nose = nose;
	}
	
	/**
	 */
	public LikenessFeatures philtrum(java.lang.String philtrum) {
		setPhiltrum(philtrum);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("philtrum")
	public java.lang.String getPhiltrum() {
		return this.philtrum;
	}
	public void setPhiltrum(java.lang.String philtrum) {
		this.philtrum = philtrum;
	}
	
	/**
	 */
	public LikenessFeatures rightBrow(java.lang.String rightBrow) {
		setRightBrow(rightBrow);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("right_brow")
	public java.lang.String getRightBrow() {
		return this.rightBrow;
	}
	public void setRightBrow(java.lang.String rightBrow) {
		this.rightBrow = rightBrow;
	}
	
	/**
	 */
	public LikenessFeatures rightCheek(java.lang.String rightCheek) {
		setRightCheek(rightCheek);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("right_cheek")
	public java.lang.String getRightCheek() {
		return this.rightCheek;
	}
	public void setRightCheek(java.lang.String rightCheek) {
		this.rightCheek = rightCheek;
	}
	
	/**
	 */
	public LikenessFeatures rightEye(java.lang.String rightEye) {
		setRightEye(rightEye);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("right_eye")
	public java.lang.String getRightEye() {
		return this.rightEye;
	}
	public void setRightEye(java.lang.String rightEye) {
		this.rightEye = rightEye;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		LikenessFeatures likenessFeatures = (LikenessFeatures) o;
		return java.util.Objects.equals(this.forehead, likenessFeatures.forehead)
				&& java.util.Objects.equals(this.jaw, likenessFeatures.jaw)
				&& java.util.Objects.equals(this.leftBrow, likenessFeatures.leftBrow)
				&& java.util.Objects.equals(this.leftCheek, likenessFeatures.leftCheek)
				&& java.util.Objects.equals(this.leftEye, likenessFeatures.leftEye)
				&& java.util.Objects.equals(this.middleForehead, likenessFeatures.middleForehead)
				&& java.util.Objects.equals(this.mouth, likenessFeatures.mouth)
				&& java.util.Objects.equals(this.nose, likenessFeatures.nose)
				&& java.util.Objects.equals(this.philtrum, likenessFeatures.philtrum)
				&& java.util.Objects.equals(this.rightBrow, likenessFeatures.rightBrow)
				&& java.util.Objects.equals(this.rightCheek, likenessFeatures.rightCheek)
				&& java.util.Objects.equals(this.rightEye, likenessFeatures.rightEye);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.forehead, this.jaw, this.leftBrow, this.leftCheek, this.leftEye, this.middleForehead, this.mouth, this.nose, this.philtrum, this.rightBrow, this.rightCheek, this.rightEye);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class LikenessFeatures {\n");
		
		sb.append("    forehead: ").append(toIndentedString(this.forehead)).append("\n");
		sb.append("    jaw: ").append(toIndentedString(this.jaw)).append("\n");
		sb.append("    leftBrow: ").append(toIndentedString(this.leftBrow)).append("\n");
		sb.append("    leftCheek: ").append(toIndentedString(this.leftCheek)).append("\n");
		sb.append("    leftEye: ").append(toIndentedString(this.leftEye)).append("\n");
		sb.append("    middleForehead: ").append(toIndentedString(this.middleForehead)).append("\n");
		sb.append("    mouth: ").append(toIndentedString(this.mouth)).append("\n");
		sb.append("    nose: ").append(toIndentedString(this.nose)).append("\n");
		sb.append("    philtrum: ").append(toIndentedString(this.philtrum)).append("\n");
		sb.append("    rightBrow: ").append(toIndentedString(this.rightBrow)).append("\n");
		sb.append("    rightCheek: ").append(toIndentedString(this.rightCheek)).append("\n");
		sb.append("    rightEye: ").append(toIndentedString(this.rightEye)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/LikenessFeatures.java <==
package com.example.model;

/**
 * Model for LikenessFeatures
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "LikenessFeatures", description = "Model for LikenessFeatures")
@javax.xml.bind.annotation.XmlRootElement(name = "LikenessFeatures")
public class LikenessFeatures implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String forehead = null;
	private java.lang.String jaw = null;
	private java.lang.String leftBrow = null;
	private java.lang.String leftCheek = null;
	private java.lang.String leftEye = null;
	private java.lang.String middleForehead = null;
	private java.lang.String mouth = null;
	private java.lang.String nose = null;
	private java.lang.String philtrum = null;
	private java.lang.String rightBrow = null;
	private java.lang.String rightCheek = null;
	private java.lang.String rightEye = null;
	
	/**
	 */
	public LikenessFeatures forehead(java.lang.String forehead) {
		setForehead(forehead);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "forehead")
	@com.fasterxml.jackson.annotation.JsonProperty("forehead")
	@javax.validation.constraints.NotNull
	public java.lang.String getForehead() {
		return this.forehead;
	}
	public void setForehead(java.lang.String forehead) {
		this.forehead = forehead;
	}
	
	/**
	 */
	public LikenessFeatures jaw(java.lang.String jaw) {
		setJaw(jaw);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "jaw")
	@com.fasterxml.jackson.annotation.JsonProperty("jaw")
	public java.lang.String getJaw() {
		return this.jaw;
	}
	public void setJaw(java.lang.String jaw) {
		this.jaw = jaw;
	}
	
	/**
	 */
	public LikenessFeatures leftBrow(java.lang.String leftBrow) {
		setLeftBrow(leftBrow);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "left_brow")
	@com.fasterxml.jackson.annotation.JsonProperty("left_brow")
	public java.lang.String getLeftBrow() {
		return this.leftBrow;
	}
	public void setLeftBrow(java.lang.String leftBrow) {
		this.leftBrow = leftBrow;
	}
	
	/**
	 */
	public LikenessFeatures leftCheek(java.lang.String leftCheek) {
		setLeftCheek(leftCheek);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "left_cheek")
	@com.fasterxml.jackson.annotation.JsonProperty("left_cheek")
	public java.lang.String getLeftCheek() {
		return this.leftCheek;
	}
	public void setLeftCheek(java.lang.String leftCheek) {
		this.leftCheek = leftCheek;
	}
	
	/**
	 */
	public LikenessFeatures leftEye(java.lang.String leftEye) {
		setLeftEye(leftEye);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "left_eye")
	@com.fasterxml.jackson.annotation.JsonProperty("left_eye")
	public java.lang.String getLeftEye() {
		return this.leftEye;
	}
	public void setLeftEye(java.lang.String leftEye) {
		this.leftEye = leftEye;
	}
	
	/**
	 */
	public LikenessFeatures middleForehead(java.lang.String middleForehead) {
		setMiddleForehead(middleForehead);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "middle_forehead")
	@com.fasterxml.jackson.annotation.JsonProperty("middle_forehead")
	public java.lang.String getMiddleForehead() {
		return this.middleForehead;
	}
	public void setMiddleForehead(java.lang.String middleForehead) {
		this.middleForehead = middleForehead;
	}
	
	/**
	 */
	public LikenessFeatures mouth(java.lang.String mouth) {
		setMouth(mouth);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "mouth")
	@com.fasterxml.jackson.annotation.JsonProperty("mouth")
	public java.lang.String getMouth() {
		return this.mouth;
	}
	public void setMouth(java.lang.String mouth) {
		this.mouth = mouth;
	}
	
	/**
	 */
	public LikenessFeatures nose(java.lang.String nose) {
		setNose(nose);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "nose")
	@com.fasterxml.jackson.annotation.JsonProperty("nose")
	public java.lang.String getNose() {
		return this.nose;
	}
	public void setNose(java.lang.String nose) {
		this.nose = nose;
	}
	
	/**
	 */
	public LikenessFeatures philtrum(java.lang.String philtrum) {
		setPhiltrum(philtrum);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "philtrum")
	@com.fasterxml.jackson.annotation.JsonProperty("philtrum")
	public java.lang.String getPhiltrum() {
		return this.philtrum;
	}
	public void setPhiltrum(java.lang.String philtrum) {
		this.philtrum = philtrum;
	}
	
	/**
	 */
	public LikenessFeatures rightBrow(java.lang.String rightBrow) {
		setRightBrow(rightBrow);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "right_brow")
	@com.fasterxml.jackson.annotation.JsonProperty("right_brow")
	public java.lang.String getRightBrow() {
		return this.rightBrow;
	}
	public void setRightBrow(java.lang.String rightBrow) {
		this.rightBrow = rightBrow;
	}
	
	/**
	 */
	public LikenessFeatures rightCheek(java.lang.String rightCheek) {
		setRightCheek(rightCheek);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "right_cheek")
	@com.fasterxml.jackson.annotation.JsonProperty("right_cheek")
	public java.lang.String getRightCheek() {
		return this.rightCheek;
	}
	public void setRightCheek(java.lang.String rightCheek) {
		this.rightCheek = rightCheek;
	}
	
	/**
	 */
	public LikenessFeatures rightEye(java.lang.String rightEye) {
		setRightEye(rightEye);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "right_eye")
	@com.fasterxml.jackson.annotation.JsonProperty("right_eye")
	public java.lang.String getRightEye() {
		return this.rightEye;
	}
	public void setRightEye(java.lang.String rightEye) {
		this.rightEye = rightEye;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		LikenessFeatures likenessFeatures = (LikenessFeatures) o;
		return java.util.Objects.equals(this.forehead, likenessFeatures.forehead)
				&& java.util.Objects.equals(this.jaw, likenessFeatures.jaw)
				&& java.util.Objects.equals(this.leftBrow, likenessFeatures.leftBrow)
				&& java.util.Objects.equals(this.leftCheek, likenessFeatures.leftCheek)
				&& java.util.Objects.equals(this.leftEye, likenessFeatures.leftEye)
				&& java.util.Objects.equals(this.middleForehead, likenessFeatures.middleForehead)
				&& java.util.Objects.equals(this.mouth, likenessFeatures.mouth)
				&& java.util.Objects.equals(this.nose, likenessFeatures.nose)
				&& java.util.Objects.equals(this.philtrum, likenessFeatures.philtrum)
				&& java.util.Objects.equals(this.rightBrow, likenessFeatures.rightBrow)
				&& java.util.Objects.equals(this.rightCheek, likenessFeatures.rightCheek)
				&& java.util.Objects.equals(this.rightEye, likenessFeatures.rightEye);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.forehead, this.jaw, this.leftBrow, this.leftCheek, this.leftEye, this.middleForehead, this.mouth, this.nose, this.philtrum, this.rightBrow, this.rightCheek, this.rightEye);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class LikenessFeatures {\n");
		
		sb.append("    forehead: ").append(toIndentedString(this.forehead)).append("\n");
		sb.append("    jaw: ").append(toIndentedString(this.jaw)).append("\n");
		sb.append("    leftBrow: ").append(toIndentedString(this.leftBrow)).append("\n");
		sb.append("    leftCheek: ").append(toIndentedString(this.leftCheek)).append("\n");
		sb.append("    leftEye: ").append(toIndentedString(this.leftEye)).append("\n");
		sb.append("    middleForehead: ").append(toIndentedString(this.middleForehead)).append("\n");
		sb.append("    mouth: ").append(toIndentedString(this.mouth)).append("\n");
		sb.append("    nose: ").append(toIndentedString(this.nose)).append("\n");
		sb.append("    philtrum: ").append(toIndentedString(this.philtrum)).append("\n");
		sb.append("    rightBrow: ").append(toIndentedString(this.rightBrow)).append("\n");
		sb.append("    rightCheek: ").append(toIndentedString(this.rightCheek)).append("\n");
		sb.append("    rightEye: ").append(toIndentedString(this.rightEye)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
